# dicfg

[![PyPI version](https://badge.fury.io/py/dicfg.svg)](https://badge.fury.io/py/dicfg)
[![tests](https://github.com/martvanrijthoven/dicfg/actions/workflows/tests.yml/badge.svg)](https://github.com/martvanrijthoven/dicfg/actions/workflows/tests.yml)
[![Coverage Status](https://coveralls.io/repos/github/martvanrijthoven/dicfg/badge.svg?branch=main)](https://coveralls.io/github/martvanrijthoven/dicfg?branch=main)
[![codeinspector](https://api.codiga.io/project/34959/score/svg)](https://app.codiga.io/public/project/34959/dicfg/dashboard)
[![docs](https://github.com/martvanrijthoven/dicfg/actions/workflows/docs.yml/badge.svg)](https://github.com/martvanrijthoven/dicfg/actions/workflows/docs.yml)
                  

Dicfg is a configuration system that supports dependency injection in config files.

## Installation

```bash
pip install dicfg
```
----


## Docs

- [https://martvanrijthoven.github.io/dicfg/](https://martvanrijthoven.github.io/dicfg/)


